@@ -6,16 +6,18 @@ class Block:
 
 	progression = Blues.standard_blues
 	
-	bpm = 200
+	bpm = 250
 	iterations = 8
 	resolution = 8
 
-
-	instruments = Bands.swing
+	swing = True
+	key = 'E'
+	instruments = Bands.jazz
 
 	def get_bpm(self, iteration):
 		return self.bpm
 
+
 	def get_instruments(self, iteration):
 		return self.instruments
 
@@ -43,7 +45,14 @@ class Block:
 	def get_resolution(self, iteration):
 		return self.resolution
 
+	def get_tick_length(self, iteration, tick_length):
+		if not self.swing:
+			return tick_length
+		else:
+			if iteration % 2 == 0:
+				return tick_length * 1.33
+			else:
+				return tick_length * 0.66
 
 
-
-
+	
