@@ -53,3 +53,9 @@ metal = [
 	PowerChords({'channel': 7}),
 	SoloInstrument({'channel':11}),
 	]
+
+jazz = [
+	SoloInstrument({'channel': 12}),
+	ChordInstrument({'channel': 1, 'max_velocity': 70, 'chance': 0.5}),
+	JazzDrum({}),
+	]
