@@ -13,7 +13,6 @@ class Sequencer:
 	meter = (4,4)
 	iterations = 0
 	play_iterations = 32
-	swing = True
 	wild = 0.4
 	paint_function = None
 	refresh_function = None
@@ -21,20 +20,27 @@ class Sequencer:
 
 	def __init__(self, song):
 		self.block = song
-		self.load_from_block()
-		self.reset_state()
+		self.block_iteration()
 
 
 	def add_instrument(self, instr):
 		self.instruments.append(instr)
 
 
-	def load_from_block(self):
-		self.progression = self.block.get_progression(self.iterations)
-		self.resolution = self.block.get_resolution(self.iterations)
-		self.instruments = self.block.get_instruments(self.iterations)
+	def block_iteration(self):
+		b = self.block
+		self.progression = b.get_progression(self.iterations)
+		self.resolution = b.get_resolution(self.iterations)
+		self.instruments = b.get_instruments(self.iterations)
+		self.set_bpm(b.get_bpm(self.iterations))
+		self.reset_state()
+	
+	def block_tick(self):
+		sleep(self.block.get_tick_length(\
+			self.iterations, self.tick_length))
 		self.set_bpm(self.block.get_bpm(self.iterations))
 
+
 	def play_instruments(self):
 
 		for instr in self.instruments:
@@ -50,12 +56,16 @@ class Sequencer:
 
 
 	def play(self):
-		self.chords = progressions.to_chords(self.progression, self.key)
+		"""Recursive loop that keeps playing until """
+		"""self.play_iterations iterations have been played."""
+		self.chords = progressions.to_chords( \
+				self.progression, self.key)
 		self.state["chords"] = self.chords
+		ticks = self.resolution / self.meter[1] * self.meter[0]
 
 		i = 0
-		ticks = self.resolution / self.meter[1] * self.meter[0]
 		while i < len(self.chords) * ticks:
+
 			chord = self.chords[ i / ticks ]
 
 			if self.refresh_function != None:
@@ -63,10 +73,12 @@ class Sequencer:
 
 			if chord != self.state["chord"]:
 				print chords.determine(chord)[0]
-				self.state["scale"] = diatonic.get_notes(self.key)
-				for note in chord:
-					if note not in self.state["scale"]:
-						self.replace_scale_note(note)
+				self.state["scale"] = \
+					diatonic.get_notes(self.key)
+				for n in chord:
+					if n not in self.state["scale"]:
+						self.replace_scale_note(n)
+
 			self.state["chord"] = chord
 			self.state["progression_index"] = i / self.resolution
 			self.state["tick"] = i % ticks
@@ -75,30 +87,21 @@ class Sequencer:
 			self.state["wild"] = self.wild
 			self.state["paint_function"] = self.paint_function
 				
+			self.play_instruments()
+
+
 			if self.update_function != None:
 				self.update_function()
-			self.play_instruments()
-			if not self.swing:
-				sleep(self.tick_length)
-			else:
-				if i % 2 == 0:
-					sleep(self.tick_length * 1.33)
-				else:
-					sleep(self.tick_length * 0.66)
-
-			self.set_bpm(self.block.get_bpm(self.iterations))
+			self.block_tick()
 			i += 1
-
 		
 		if self.play_iterations != 1:
-			print "-" * 20
 			self.iterations += 1
 			self.play_iterations -= 1
-			self.load_from_block()
-			self.reset_state()
+			self.block_iteration()
+			print "-" * 20
 			return self.play()
-		else:
-			return self.simple_ending()
+		return self.simple_ending()
 
 	def simple_ending(self):
 		self.state["chord"] = self.chords[0]
